Index: /trunk/src/VBox/Frontends/VirtualBox/src/globals/VBoxGlobal.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/globals/VBoxGlobal.cpp	(revision 57589)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/globals/VBoxGlobal.cpp	(revision 57590)
@@ -346,4 +346,16 @@
 }
 
+int VBoxGlobal::screenNumber(const QWidget *pWidget) const
+{
+    /* Redirect call to QDesktopWidget: */
+    return QApplication::desktop()->screenNumber(pWidget);
+}
+
+int VBoxGlobal::screenNumber(const QPoint &point) const
+{
+    /* Redirect call to QDesktopWidget: */
+    return QApplication::desktop()->screenNumber(point);
+}
+
 const QRect VBoxGlobal::screenGeometry(int iHostScreenIndex /* = -1 */) const
 {
@@ -372,14 +384,26 @@
 }
 
-const QRect VBoxGlobal::screenGeometry(QWidget *pWidget /* = 0 */) const
+const QRect VBoxGlobal::screenGeometry(const QWidget *pWidget) const
 {
     /* Redirect call to existing wrapper: */
-    return screenGeometry(QApplication::desktop()->screenNumber(pWidget));
-}
-
-const QRect VBoxGlobal::availableGeometry(QWidget *pWidget /* = 0 */) const
+    return screenGeometry(screenNumber(pWidget));
+}
+
+const QRect VBoxGlobal::availableGeometry(const QWidget *pWidget) const
 {
     /* Redirect call to existing wrapper: */
-    return availableGeometry(QApplication::desktop()->screenNumber(pWidget));
+    return availableGeometry(screenNumber(pWidget));
+}
+
+const QRect VBoxGlobal::screenGeometry(const QPoint &point) const
+{
+    /* Redirect call to existing wrapper: */
+    return screenGeometry(screenNumber(point));
+}
+
+const QRect VBoxGlobal::availableGeometry(const QPoint &point) const
+{
+    /* Redirect call to existing wrapper: */
+    return availableGeometry(screenNumber(point));
 }
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/globals/VBoxGlobal.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/globals/VBoxGlobal.h	(revision 57589)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/globals/VBoxGlobal.h	(revision 57590)
@@ -145,4 +145,9 @@
         int screenCount() const;
 
+        /** Returns the index of the screen which contains contains @a pWidget. */
+        int screenNumber(const QWidget *pWidget) const;
+        /** Returns the index of the screen which contains contains @a point. */
+        int screenNumber(const QPoint &point) const;
+
         /** Returns the geometry of the host-screen with @a iHostScreenIndex.
           * @note The default screen is used if @a iHostScreenIndex is -1. */
@@ -152,10 +157,13 @@
         const QRect availableGeometry(int iHostScreenIndex = -1) const;
 
-        /** Returns the geometry of the host-screen which contains @a pWidget.
-          * @note The default screen is used if @a pWidget is 0. */
-        const QRect screenGeometry(QWidget *pWidget = 0) const;
-        /** Returns the available-geometry of the host-screen which contains @a pWidget.
-          * @note The default screen is used if @a pWidget is 0. */
-        const QRect availableGeometry(QWidget *pWidget = 0) const;
+        /** Returns the geometry of the host-screen which contains @a pWidget. */
+        const QRect screenGeometry(const QWidget *pWidget) const;
+        /** Returns the available-geometry of the host-screen which contains @a pWidget. */
+        const QRect availableGeometry(const QWidget *pWidget) const;
+
+        /** Returns the geometry of the host-screen which contains @a point. */
+        const QRect screenGeometry(const QPoint &point) const;
+        /** Returns the available-geometry of the host-screen which contains @a point. */
+        const QRect availableGeometry(const QPoint &point) const;
     /** @} */
 
